@@ -75,7 +75,7 @@ public:
 
   bool fixTransactionCommodity(const MyMoneyAccount& /* account */) override;
 
-  void totalAmount(MyMoneyMoney& amount) const;
+  MyMoneyMoney totalAmount() const;
 
   bool setupPrice(const MyMoneyTransaction& t, MyMoneySplit& split);
 
@@ -122,9 +122,7 @@ protected Q_SLOTS:
   void slotUpdateActivity(eMyMoney::Split::InvestmentTransactionType);
   void slotUpdateSecurity(const QString& stockId);
   void slotUpdateInterestCategory(const QString& id);
-  void slotUpdateInterestVisibility(const QString&);
   void slotUpdateFeeCategory(const QString& id);
-  void slotUpdateFeeVisibility(const QString&);
   void slotUpdateTotalAmount();
   void slotTransactionContainerGeometriesUpdated();
   void slotUpdateInvestMemoState();
@@ -140,7 +138,7 @@ protected:
     * This method (re-)loads the widgets with the transaction information
     * contained in @a m_transaction and @a m_split.
     *
-    * @param action preset the edit wigdets for @a action if no transaction
+    * @param action preset the edit widgets for @a action if no transaction
     *               is present
     */
   void loadEditWidgets(eWidgets::eRegister::Action action) override;
